\name{StatDataML-internal}
\alias{readDimensionSDML}
\alias{writeDimensionSDML}
\alias{readDfSDML}
\alias{catSDML}
\alias{etagsSDML}
\alias{getAttrSDML}
\alias{handlersSDML}
\alias{writeDatasetSDML}
\alias{readArraySDML}
\alias{readListSDML}
\alias{writeDescriptionSDML}
\alias{readDatasetSDML}
\alias{readProperties}
\alias{writeDfSDML}
\alias{readDescriptionSDML}
\alias{writePropertiesSDML}
\alias{getDataSDML}
\alias{getComplexDataSDML}
\alias{default}
\alias{readType}
\alias{writeTypeSDML}
\alias{tags}
\alias{getTextDataSDML}
\alias{cetagsSDML}
\alias{readCategoriesSDML}
\alias{writeCategoriesSDML}
\alias{writeListArraySDML}
\title{Internal StatDataML functions}
\description{
  Internal StatDataML functions.
}
\usage{}
\details{
  These are not to be called by the user.
}
\keyword{internal}

\eof
\name{readSDML}
\alias{readSDML}
\title{Read StatDataML Files}
\description{
  Read a StatDataML file and create a corresponding R object.
}
\usage{
readSDML(file="", text=NULL, validate=FALSE, read.description=FALSE)
}
\arguments{
  \item{file}{the StatDataML file to be read.}
  \item{text}{a string containing StatDataML code (if no file is specified).}
  \item{validate}{logical, should \code{file} be validated using the DTD
    specified in \code{file}?} 
  \item{read.description}{logical, should the \code{description} tag in
    \code{file} be read?} 
}
\details{For details on the \code{StatDataML} format see the proposal.
}
\value{
  a data object with an additional \code{SDMLdescription} attribute}
\author{Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> and Friedrich Leisch
  <leisch@ci.tuwien.ac.at>}
\seealso{see also \code{\link{writeSDML}}}

\examples{
library(XML)

# write/read vector with names
a <- 1:15
names(a) <- paste("n", 1:15, sep="")
writeSDML(a, "testvec.xml")
b <- readSDML("testvec.xml")
cat(" a is equal b :", all.equal(a,b), "\n")


# write/read a matrix
A <- matrix(1:16, ncol=4)
rownames(A) <- paste("row", 1:4, sep="")
colnames(A) <- paste("col", 1:4, sep="")
writeSDML(A, "testmat.sdml")
B <- readSDML("testmat.sdml")
cat(" A is equal B :", all.equal(A,B), "\n")

# write/read a data.frame
data(iris)
writeSDML(iris, "iris.sdml")
irisSDML <- readSDML("iris.sdml")
cat(" iris is equal irisSDML: ", all.equal(iris,irisSDML), "\n")

# write/read a ts object
data(airmiles)
writeSDML(airmiles, "air.sdml")
airSDML <- readSDML("air.sdml")
cat(" airmiles is equal airSDML: ", all.equal(airmiles,airSDML), "\n")

# write/read the islands data
data(islands)
writeSDML(islands, "islands.sdml")
islandsSDML <- readSDML("islands.sdml")
cat(" islands is equal islandsSDML: ", all.equal(islands,islandsSDML), "\n")

}
\keyword{file}

\eof
\name{writeSDML}
\alias{writeSDML}
\title{Write Data in StatDataML Format}
\description{
  Write data in StatDataML format, either in a file or to
  standard output
}
\usage{
writeSDML(x, file = "", textdata = NULL, dtd = NULL, sep = " \\n",
na.string = "NA", null.string = "NULL", posinf.string = "+Inf",
neginf.string = "-Inf", nan.string = "NaN", true = "1", false = "0",
title = deparse(substitute(x)), source = "R", version = " ",
date = NULL, comment = " ", properties = NULL) 
}
\arguments{
  \item{x}{a data object.}
  \item{file}{the name of the file to write to. }
  \item{textdata}{save array elements as \code{textdata} blocks instead
    of \code{data}?   Numeric arrays are by default
    (\code{textdata=NULL}) saved in \code{textdata} blocks, character
    arrays in \code{data} blocks.}
  \item{dtd}{location of the StatDataML DTD.}
  \item{sep}{field separator for \code{textdata} blocks.}
  \item{na.string}{the string which should be interpreted as \code{NA} element.}
  \item{null.string}{the string which should be interpreted as NULL
    string.}
  \item{posinf.string}{the string which should be interpreted as \code{+Inf}.}
  \item{neginf.string}{the string which should be interpreted as \code{-Inf}.}
  \item{nan.string}{the string which should be interpreted as
    \code{NaN}.}
  \item{true, false}{the strings which should be interpreted as \code{TRUE}/\code{FALSE}.}
  \item{title}{the title of the data being saved (string).}
  \item{source}{the source of the data being saved (string).}
  \item{version}{the version of the data being saved (string).}
  \item{comment}{a free form commentary for the data being saved (string).}
  \item{date}{a free form date element, date() by default.}
  \item{properties}{an arbitrary list or array.}
}
\details{\code{info} attributes of arrays are used for the 
  \code{info} attributes of the \code{e} / \code{ce} / \code{na} tags
  in StatDataML. For further details on the \code{StatDataML} format see the proposal.
}
\author{Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> and Friedrich
  Leisch<leisch@ci.tuwien.ac.at>} 
\seealso{\code{\link{readSDML}}}

\examples{
A <- matrix(1:16, ncol=4)
rownames(A) <- paste("row", 1:4, sep="")
colnames(A) <- paste("col", 1:4, sep="")
writeSDML(A, "testmat.sdml")

I <- letters[1:16]
attr(A, "info") <- I
writeSDML(A, "testmat2.sdml", textdata = FALSE)
}
\keyword{file}

\eof
